@@ -5,8 +5,8 @@ setMethod("dissimilarity",
           signature(x = "TermDocMatrix", y = "ANY", method = "character"),
           function(x, y = NULL, method) {
               # Until factored out in a seperate package
-              # use the \code{dists} function from the \pkg{cba} package
-              dists(as(Data(x), "matrix"), y, method)
+              # use the \code{dist} function from the \pkg{proxy} package
+              proxy::dist(as(Data(x), "matrix"), y, method)
           })
 setMethod("dissimilarity",
           signature(x = "TextDocument", y = "TextDocument", method = "character"),
